@@ -14,7 +14,7 @@ sub get_demo_box {
 		Description(top => '3em', textNode => '
 			Adapted from the original Mozilla XUL periodic table, by Alice J.
 			Corbin. It is the definitive example of all xul widgets. You can
-			fint it at:
+			find it at:
 		'),
 		Box(HTML_Div(HTML_A(
 			style    => 'padding-left: 4em; padding-bottom: 3em',
@@ -27,20 +27,12 @@ sub get_demo_box {
 			Caption(label => 'CAVEATS'),
 			HTML_Pre(textNode => << 'CAVEATS_TEXT'),
 
-MAJOR ISSUES
+CAVEATS
 			
   * multiple selection is not supported
-  * multi column list box does not show 1st column labels
-    for some rows
   * trees are not supported yet
   * popups are not supported yet
 
-MINOR ISSUES
-
-  * equalsize attribute will not work
-  * multiline labels in button may come out in wrong order
-  * menus with no popups may not show
-
 CAVEATS_TEXT
 		),
 	);
